@@ -9,7 +9,7 @@ use Log::Log4perl qw( get_logger );
 use Workflow::Exception qw( workflow_error condition_error );
 
 $Workflow::Condition::CACHE_RESULTS = 1;
-$Workflow::Condition::VERSION = '1.55';
+$Workflow::Condition::VERSION = '1.56';
 
 my $log;
 my @FIELDS = qw( name class );
@@ -94,7 +94,8 @@ sub evaluate_condition {
 
         } else {
             $wf->{'_condition_result_cache'}->{$orig_condition} = $return_value;
-            $log->debug("condition '$orig_condition' succeeded");
+            $log->debug("condition '$orig_condition' succeeded; returned: ",
+                        $return_value ? 'true' : 'false');
             return $return_value;
         }
         # unreachable
@@ -117,7 +118,7 @@ Workflow::Condition - Evaluate a condition depending on the workflow state and e
 
 =head1 VERSION
 
-This documentation describes version 1.55 of this package
+This documentation describes version 1.56 of this package
 
 =head1 SYNOPSIS
 
