@@ -8,7 +8,7 @@ use Log::Log4perl qw( get_logger );
 use Workflow::Exception qw( configuration_error workflow_error );
 use Carp qw(croak);
 use English qw( -no_match_vars );
-$Workflow::Factory::VERSION = '1.55';
+$Workflow::Factory::VERSION = '1.56';
 
 # Extra action attribute validation is off by default for compatibility.
 our $VALIDATE_ACTION_CONFIG = 0;
@@ -363,7 +363,8 @@ sub create_workflow {
 
     my $state = $wf->_get_workflow_state();
     if ( $state->autorun ) {
-        $self->log->info( "State '$state' marked to be run ",
+        my $state_name = $state->name;
+        $self->log->info( "State '$state_name' marked to be run ",
                           "automatically; executing that state/action..." );
         $wf->_auto_execute_state($state);
     }
@@ -811,7 +812,7 @@ Workflow::Factory - Generates new workflow and supporting objects
 
 =head1 VERSION
 
-This documentation describes version 1.55 of this package
+This documentation describes version 1.56 of this package
 
 =head1 SYNOPSIS
 
