@@ -7,7 +7,7 @@ use Log::Log4perl qw( get_logger );
 use Workflow::Exception qw( configuration_error persist_error );
 use English qw( -no_match_vars );
 
-$Workflow::Persister::DBI::ExtraData::VERSION = '1.55';
+$Workflow::Persister::DBI::ExtraData::VERSION = '1.56';
 
 my @FIELDS = qw( table data_field context_key );
 __PACKAGE__->mk_accessors(@FIELDS);
@@ -42,7 +42,9 @@ sub init {
         $self->context_key($context_key);
     }
     $self->log->info( "Configured extra data fetch with: ",
-                      join '; ', $self->table, $data_field, $self->context_key );
+                      join( '; ', $self->table, $data_field,
+                            ( defined $self->context_key
+                              ? $self->context_key : '' ) ) );
 }
 
 sub fetch_extra_workflow_data {
@@ -104,7 +106,7 @@ Workflow::Persister::DBI::ExtraData - Fetch extra data with each workflow and pu
 
 =head1 VERSION
 
-This documentation describes version 1.55 of this package
+This documentation describes version 1.56 of this package
 
 =head1 SYNOPSIS
 
